﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Web;
using System.Web.Mvc;

using ImplementAPI.Models;
using ImplementAPI.Class;
using System.Text;
using System.Net;
using System.IO;
using Newtonsoft.Json;

namespace ImplementAPI.Controllers
{
    public class APICallController : Controller
    {
        public ActionResult Index(string key, string secret, int? page)
        {
            if (page != null)
                GetProduct(key, secret, Convert.ToInt32(page));
            return View();
        }

        [HttpPost]
        [ActionName("Index")]
        public ActionResult Index_Post(string key, string secret, int? page)
        {
            if (string.IsNullOrEmpty(key))
                ModelState.AddModelError("key", "Please enter API Key");

            if (string.IsNullOrEmpty(secret))
                ModelState.AddModelError("secret", "Please enter API Secret");

            if (ModelState.IsValid)
                GetProduct(key, secret, Convert.ToInt32(page));

            return View();
        }

        public void GetProduct(string key, string secret, int page)
        {
            int pageNo = page == 0 ? 1 : Convert.ToInt32(page);

            HttpWebRequest apiRequest = WebRequest.Create("http://" + Request.Url.Authority + "/api/API/" + pageNo + "") as HttpWebRequest;
            //HttpWebRequest apiRequest = WebRequest.Create("http://www.demo.yogihosting.com/mvc/api/API/"+pageNo+"") as HttpWebRequest;
            apiRequest.Headers.Add("Key", key);
            apiRequest.Headers.Add("Secret", secret);

            StringBuilder sb = new StringBuilder();
            string apiResponse = "";
            try
            {
                using (HttpWebResponse response = apiRequest.GetResponse() as HttpWebResponse)
                {
                    StreamReader reader = new StreamReader(response.GetResponseStream());
                    apiResponse = reader.ReadToEnd();

                    ResponseAPICallProduct rootObject = JsonConvert.DeserializeObject<ResponseAPICallProduct>(apiResponse);
                    sb.Append("<div class=\"resultDiv\"><table><tr><td>Product Id</td><td>Product Name</td><td>Supplier Id</td><td>Category Id</td><td>Quantity Per Unit</td><td>Unit Price</td><td>Units In Stock</td><td>Units On Order</td><td>Reorder Level</td><td>Discontinued</td></tr>");
                    foreach (APICallProduct product in rootObject.Product)
                    {
                        sb.Append("<tr><td>" + product.ProductID + "</td><td>" + product.ProductName + "</td><td>" + product.SupplierID + "</td><td>" + product.CategoryID + "</td><td>" + product.QuantityPerUnit + "</td><td>" + product.UnitPrice + "</td><td>" + product.UnitsInStock + "</td><td>" + product.UnitsOnOrder + "</td><td>" + product.ReorderLevel + "</td><td>" + product.Discontinued + "</td></tr>");
                    }
                    sb.Append("</table></div>");

                    int pageSize = 10;
                    PagingInfo pagingInfo = new PagingInfo();
                    pagingInfo.CurrentPage = pageNo;
                    pagingInfo.TotalItems = rootObject.Total;
                    pagingInfo.ItemsPerPage = pageSize;
                    ViewBag.Paging = pagingInfo;
                }
            }
            catch (System.Net.WebException ex)
            {
                sb.Append(ex.Message);
            }

            ViewBag.Result = sb.ToString();
        }

        public ActionResult Search(string name)
        {
            return View();
        }

        [HttpPost]
        [ActionName("Search")]
        public ActionResult Search_Post(string name)
        {
            if (string.IsNullOrEmpty(name))
            {
                ModelState.AddModelError("name", "Please enter your name");
            }

            if (ModelState.IsValid)
            {
                string key = "Key1", secret = "Secret1";
                HttpWebRequest apiRequest = WebRequest.Create("http://" + Request.Url.Authority + "/api/API/" + name + "") as HttpWebRequest;
                //HttpWebRequest apiRequest = WebRequest.Create("http://www.demo.yogihosting.com/mvc/api/API/"+name+"") as HttpWebRequest;
                apiRequest.Method = "Post";
                apiRequest.ContentType = "application/x-www-form-urlencoded";
                apiRequest.ContentLength = 0;

                apiRequest.Headers.Add("Key", key);
                apiRequest.Headers.Add("Secret", secret);

                StringBuilder sb = new StringBuilder();
                string apiResponse = "";

                try
                {
                    using (HttpWebResponse response = apiRequest.GetResponse() as HttpWebResponse)
                    {
                        StreamReader reader = new StreamReader(response.GetResponseStream());
                        apiResponse = reader.ReadToEnd();

                        ResponseAPICallProduct rootObject = JsonConvert.DeserializeObject<ResponseAPICallProduct>(apiResponse);
                        sb.Append("<div class=\"resultDiv\"><table><tr><td>Product Id</td><td>Product Name</td><td>Supplier Id</td><td>Category Id</td><td>Quantity Per Unit</td><td>Unit Price</td><td>Units In Stock</td><td>Units On Order</td><td>Reorder Level</td><td>Discontinued</td></tr>");
                        foreach (APICallProduct product in rootObject.Product)
                            sb.Append("<tr><td>" + product.ProductID + "</td><td>" + product.ProductName + "</td><td>" + product.SupplierID + "</td><td>" + product.CategoryID + "</td><td>" + product.QuantityPerUnit + "</td><td>" + product.UnitPrice + "</td><td>" + product.UnitsInStock + "</td><td>" + product.UnitsOnOrder + "</td><td>" + product.ReorderLevel + "</td><td>" + product.Discontinued + "</td></tr>");

                        sb.Append("</table></div>");
                    }
                }
                catch (System.Net.WebException ex)
                {
                    sb.Append(ex.Message);
                }

                ViewBag.Result = sb.ToString();
            }

            return View();
        }
    }
}